# lifted - a minimal parser combinator library.

See tests for example usage.

## Building distribution

```
python setup.py sdist bdist_wheel
```

## Uploading distribution
```
pipenv shell
twine upload dist/*
```
